﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Linq;
using alglib;
using HeuristicLab.Core;
using HeuristicLab.Data;
using HeuristicLab.Operators;
using HeuristicLab.Optimization;
using HeuristicLab.Parameters;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using HeuristicLab.Encodings.SymbolicExpressionTreeEncoding;

namespace HeuristicLab.Problems.DataAnalysis.Operators {
  [Item("DynamicDepthLimitInitializer", "")]
  [StorableClass]
  public class DynamicDepthLimitInitializer : SingleSuccessorOperator {
    public IValueLookupParameter<IntValue> DynamicDepthLimitParameter {
      get { return (IValueLookupParameter<IntValue>)Parameters["DynamicDepthLimit"]; }
    }
    public IValueLookupParameter<IntValue> InitialDepthLimitParameter {
      get { return (IValueLookupParameter<IntValue>)Parameters["InitialDepthLimit"]; }
    }

    public DynamicDepthLimitInitializer()
      : base() {
      Parameters.Add(new ValueLookupParameter<IntValue>("DynamicDepthLimit", "The current depth limit."));
      Parameters.Add(new ValueLookupParameter<IntValue>("InitialDepthLimit", "The initial depth limit."));
    }

    public override IOperation Apply() {
      int ddl = InitialDepthLimitParameter.ActualValue.Value;
      DynamicDepthLimitParameter.ActualValue = new IntValue(ddl);
      return base.Apply();
    }
  }
}
